# riscv-tests-prebuilt-binaries

This repo hosts pre-built binaries for the [official RISC-V test suite](https://github.com/riscv-software-src/riscv-tests).

Binaries were built under Ubuntu 22.10 (X86-64) using the mainline riscv-gnu-toolchain. Currently, only the `isa/rv32ui/` tests are provided.
